@@ -357,6 +357,11 @@ Desc decoder_profiles[] = {
 {"H264_PROGRESSIVE_HIGH",       VDP_DECODER_PROFILE_H264_PROGRESSIVE_HIGH},
 {"H264_CONSTRAINED_HIGH",       VDP_DECODER_PROFILE_H264_CONSTRAINED_HIGH},
 {"H264_HIGH_444_PREDICTIVE",    VDP_DECODER_PROFILE_H264_HIGH_444_PREDICTIVE},
+{"HEVC_MAIN",                   VDP_DECODER_PROFILE_HEVC_MAIN},
+{"HEVC_MAIN_10",                VDP_DECODER_PROFILE_HEVC_MAIN_10},
+{"HEVC_MAIN_STILL",             VDP_DECODER_PROFILE_HEVC_MAIN_STILL},
+{"HEVC_MAIN_12",                VDP_DECODER_PROFILE_HEVC_MAIN_12},
+{"HEVC_MAIN_444",               VDP_DECODER_PROFILE_HEVC_MAIN_444},
 };
 const size_t decoder_profile_count = sizeof(decoder_profiles)/sizeof(Desc);
 
